@@ -1,4 +1,4 @@
-"""Provides the code to load PRAW's configuration file `praw.ini`."""
+"""Provides the code to load PRAW's configuration file ``praw.ini``."""
 import configparser
 import os
 import sys
@@ -19,7 +19,7 @@ class _NotSet:
 
 
 class Config:
-    """A class containing the configuration for a reddit site."""
+    """A class containing the configuration for a Reddit site."""
 
     CONFIG = None
     CONFIG_NOT_SET = _NotSet()  # Represents a config value that is not set.
@@ -36,7 +36,7 @@ class Config:
         return item.lower() in {"1", "yes", "true", "on"}
 
     @classmethod
-    def _load_config(cls, config_interpolation: Optional[str] = None):
+    def _load_config(cls, *, config_interpolation: Optional[str] = None):
         """Attempt to load settings from various praw.ini files."""
         if config_interpolation is not None:
             interpolator_class = cls.INTERPOLATION_LEVEL[config_interpolation]()
@@ -75,10 +75,10 @@ class Config:
         config_interpolation: Optional[str] = None,
         **settings: str,
     ):
-        """Initialize a Config instance."""
+        """Initialize a :class:`.Config` instance."""
         with Config.LOCK:
             if Config.CONFIG is None:
-                self._load_config(config_interpolation)
+                self._load_config(config_interpolation=config_interpolation)
 
         self._settings = settings
         self.custom = dict(Config.CONFIG.items(site_name), **settings)
@@ -94,7 +94,7 @@ class Config:
         del self.custom[key]
         return value
 
-    def _fetch_default(self, key, default=None):
+    def _fetch_default(self, key, *, default=None):
         if key not in self.custom:
             return default
         return self._fetch(key)
@@ -112,13 +112,13 @@ class Config:
     def _initialize_attributes(self):
         self._short_url = self._fetch_default("short_url") or self.CONFIG_NOT_SET
         self.check_for_async = self._config_boolean(
-            self._fetch_default("check_for_async", True)
+            self._fetch_default("check_for_async", default=True)
         )
         self.check_for_updates = self._config_boolean(
             self._fetch_or_not_set("check_for_updates")
         )
         self.warn_comment_sort = self._config_boolean(
-            self._fetch_default("warn_comment_sort", True)
+            self._fetch_default("warn_comment_sort", default=True)
         )
         self.kinds = {
             x: self._fetch(f"{x}_kind")
