@@ -4,6 +4,7 @@ from json import dumps
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from ...const import API_PATH
+from ...util import _deprecate_args
 from ...util.cache import cachedproperty
 from ..listing.mixins import SubredditListingMixin
 from .base import RedditBase
@@ -15,20 +16,15 @@ if TYPE_CHECKING:  # pragma: no cover
 
 
 class Multireddit(SubredditListingMixin, RedditBase):
-    r"""A class for users' Multireddits.
+    r"""A class for users' multireddits.
 
-    This is referred to as a Custom Feed on the Reddit UI.
+    This is referred to as a "Custom Feed" on the Reddit UI.
 
-    **Typical Attributes**
+    .. include:: ../../typical_attributes.rst
 
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
-
-    ==================== =============================================================
+    ==================== ==============================================================
     Attribute            Description
-    ==================== =============================================================
+    ==================== ==============================================================
     ``can_edit``         A ``bool`` representing whether or not the authenticated user
                          may edit the multireddit.
     ``copied_from``      The multireddit that the multireddit was copied from, if it
@@ -40,11 +36,10 @@ class Multireddit(SubredditListingMixin, RedditBase):
     ``name``             The name of the multireddit.
     ``over_18``          A ``bool`` representing whether or not the multireddit is
                          restricted for users over 18.
-    ``subreddits``       A ``list`` of :class:`.Subreddit`\ s that make up the
-                         multireddit.
-    ``visibility``       The visibility of the multireddit, either ``private``,
-                         ``public``, or ``hidden``.
-    ==================== =============================================================
+    ``subreddits``       A list of :class:`.Subreddit`\ s that make up the multireddit.
+    ``visibility``       The visibility of the multireddit, either ``"private"``,
+                         ``"public"``, or ``"hidden"``.
+    ==================== ==============================================================
 
     .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
@@ -59,7 +54,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         :param title: The title to make a slug of.
 
-        Adapted from reddit's utils.py.
+        Adapted from Reddit's utils.py.
 
         """
         title = Multireddit.RE_INVALID.sub("_", title).strip("_").lower()
@@ -79,7 +74,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            for comment in reddit.multireddit("spez", "fun").stream.comments():
+            for comment in reddit.multireddit(redditor="spez", name="fun").stream.comments():
                 print(comment)
 
         Additionally, new submissions can be retrieved via the stream. In the following
@@ -87,14 +82,16 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            for submission in reddit.multireddit("bboe", "games").stream.submissions():
+            for submission in reddit.multireddit(
+                redditor="bboe", name="games"
+            ).stream.submissions():
                 print(submission)
 
         """
         return SubredditStream(self)
 
     def __init__(self, reddit: "praw.Reddit", _data: Dict[str, Any]):
-        """Construct an instance of the Multireddit object."""
+        """Initialize a :class:`.Multireddit` instance."""
         self.path = None
         super().__init__(reddit, _data=_data)
         self._author = Redditor(reddit, self.path.split("/", 3)[2])
@@ -103,18 +100,6 @@ class Multireddit(SubredditListingMixin, RedditBase):
         if "subreddits" in self.__dict__:
             self.subreddits = [Subreddit(reddit, x["name"]) for x in self.subreddits]
 
-    def _fetch_info(self):
-        return (
-            "multireddit_api",
-            {"multi": self.name, "user": self._author.name},
-            None,
-        )
-
-    def _fetch_data(self):
-        name, fields, params = self._fetch_info()
-        path = API_PATH[name].format(**fields)
-        return self._reddit.request("GET", path, params)
-
     def _fetch(self):
         data = self._fetch_data()
         data = data["data"]
@@ -122,17 +107,29 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self.__dict__.update(other.__dict__)
         self._fetched = True
 
+    def _fetch_data(self):
+        name, fields, params = self._fetch_info()
+        path = API_PATH[name].format(**fields)
+        return self._reddit.request(method="GET", params=params, path=path)
+
+    def _fetch_info(self):
+        return (
+            "multireddit_api",
+            {"multi": self.name, "user": self._author.name},
+            None,
+        )
+
     def add(self, subreddit: "praw.models.Subreddit"):
         """Add a subreddit to this multireddit.
 
         :param subreddit: The subreddit to add to this multi.
 
-        For example, to add subreddit ``r/test`` to multireddit ``bboe/test``:
+        For example, to add r/test to multireddit ``bboe/test``:
 
         .. code-block:: python
 
             subreddit = reddit.subreddit("test")
-            reddit.multireddit("bboe", "test").add(subreddit)
+            reddit.multireddit(redditor="bboe", name="test").add(subreddit)
 
         """
         url = API_PATH["multireddit_update"].format(
@@ -141,19 +138,19 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self._reddit.put(url, data={"model": dumps({"name": str(subreddit)})})
         self._reset_attributes("subreddits")
 
-    def copy(self, display_name: Optional[str] = None) -> "praw.models.Multireddit":
+    @_deprecate_args("display_name")
+    def copy(self, *, display_name: Optional[str] = None) -> "praw.models.Multireddit":
         """Copy this multireddit and return the new multireddit.
 
-        :param display_name: (optional) The display name for the copied multireddit.
-            Reddit will generate the ``name`` field from this display name. When not
-            provided the copy will use the same display name and name as this
-            multireddit.
+        :param display_name: The display name for the copied multireddit. Reddit will
+            generate the ``name`` field from this display name. When not provided the
+            copy will use the same display name and name as this multireddit.
 
-        To copy the multireddit ``bboe/test`` with a name of ``testing``:
+        To copy the multireddit ``bboe/test`` with a name of ``"testing"``:
 
         .. code-block:: python
 
-            reddit.multireddit("bboe", "test").copy("testing")
+            reddit.multireddit(redditor="bboe", name="test").copy(display_name="testing")
 
         """
         if display_name:
@@ -173,11 +170,11 @@ class Multireddit(SubredditListingMixin, RedditBase):
     def delete(self):
         """Delete this multireddit.
 
-        For example, to delete multireddit``bboe/test``:
+        For example, to delete multireddit ``bboe/test``:
 
         .. code-block:: python
 
-            reddit.multireddit("bboe", "test").delete()
+            reddit.multireddit(redditor="bboe", name="test").delete()
 
         """
         path = API_PATH["multireddit_api"].format(
@@ -190,12 +187,12 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         :param subreddit: The subreddit to remove from this multi.
 
-        For example, to remove subreddit ``r/test`` from multireddit ``bboe/test``:
+        For example, to remove r/test from multireddit ``bboe/test``:
 
         .. code-block:: python
 
             subreddit = reddit.subreddit("test")
-            reddit.multireddit("bboe", "test").remove(subreddit)
+            reddit.multireddit(redditor="bboe", name="test").remove(subreddit)
 
         """
         url = API_PATH["multireddit_update"].format(
@@ -219,22 +216,22 @@ class Multireddit(SubredditListingMixin, RedditBase):
             than 50 characters.
         :param subreddits: Subreddits for this multireddit.
         :param description_md: Description for this multireddit, formatted in Markdown.
-        :param icon_name: Can be one of: ``art and design``, ``ask``, ``books``,
-            ``business``, ``cars``, ``comics``, ``cute animals``, ``diy``,
-            ``entertainment``, ``food and drink``, ``funny``, ``games``, ``grooming``,
-            ``health``, ``life advice``, ``military``, ``models pinup``, ``music``,
-            ``news``, ``philosophy``, ``pictures and gifs``, ``science``, ``shopping``,
-            ``sports``, ``style``, ``tech``, ``travel``, ``unusual stories``, ``video``,
-            or ``None``.
+        :param icon_name: Can be one of: ``"art and design"``, ``"ask"``, ``"books"``,
+            ``"business"``, ``"cars"``, ``"comics"``, ``"cute animals"``, ``"diy"``,
+            ``"entertainment"``, ``"food and drink"``, ``"funny"``, ``"games"``,
+            ``"grooming"``, ``"health"``, ``"life advice"``, ``"military"``, ``"models
+            pinup"``, ``"music"``, ``"news"``, ``"philosophy"``, ``"pictures and
+            gifs"``, ``"science"``, ``"shopping"``, ``"sports"``, ``"style"``,
+            ``"tech"``, ``"travel"``, ``"unusual stories"``, ``"video"``, or ``None``.
         :param key_color: RGB hex color code of the form ``"#FFFFFF"``.
-        :param visibility: Can be one of: ``hidden``, ``private``, ``public``.
-        :param weighting_scheme: Can be one of: ``classic``, ``fresh``.
+        :param visibility: Can be one of: ``"hidden"``, ``"private"``, or ``"public"``.
+        :param weighting_scheme: Can be one of: ``"classic"`` or ``"fresh"``.
 
-        For example, to rename multireddit ``bboe/test`` to ``bboe/testing``:
+        For example, to rename multireddit ``"bboe/test"`` to ``"bboe/testing"``:
 
         .. code-block:: python
 
-            reddit.multireddit("bboe", "test").update(display_name="testing")
+            reddit.multireddit(redditor="bboe", name="test").update(display_name="testing")
 
         """
         if "subreddits" in updated_settings:
